@@ -33,14 +33,14 @@ public:
 
     void start() override;
 
-private Q_SLOTS:
+private:
     void slotCheckBackupResource();
     void slotCheckBackupConfig();
     void slotAlarmJobTerminated();
     void slotWriteNextArchiveResource();
-private:
+
     void backupConfig();
-    int mIndexIdentifier;
+    int mIndexIdentifier = 0;
 };
 
 #endif // EXPORTALARMJOB_H
